pub fn request_stats_now()Expand description
Request stats will request the subcomponents to send their stats now, rather than waiting for their periodic sending.
pub fn request_stats_now()Request stats will request the subcomponents to send their stats now, rather than waiting for their periodic sending.